bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 30. Aventiure
___________________________________________________ #### Aventivre wie die kvnige mit ir rechen slafen giengen #### vnd wie in do geschach
###### 1818 | ### Der tach der hete nv ende | vnd nahet in div naht ### di wegmveden rechen | ir sorge si an vaht ### wanne si solden ruwen | vnd an ir bette gan ### daz beredete hagene | ez wart in shiere chvnt getan
###### 1819 | ### gventher sprach ce dem wirte | got laz ivch wol geleben ### wir wellen varn slaffen | ir svlt vns vrlovb geben ### swenne ir daz gebietet | so chom wir morgen frvo ### er shiet von sinen gesten | vil harte vroelichen do
###### 1820 | ### dringen allenthalben | di geste man do sach ### volker der chvene | zv den hivnen sprach ### wi getvrret ir den rechen | fver di fveze gan ### vnde welt irs ivch niht miden | so wirt iv leide getan
###### 1821 | ### so slah ich etelichem | so swaeren gegenslalch ### hat er getriwer iemen | der ez beweinen mach ### wan wichet ir vns rechen | ia dvnchet ez mich gvt ### ez heizent allez degene | vnde sint geliche niht gemvt
###### 1822 | ### do der videlaere | so zornechlichen sprach ### hagen der chvene | hinder sich do sach ### er sprach iv ratet rehte | der chvene spileman ### ir criemhilde helde | ir svlt cen herbergen gan
###### 1823 | ### des ir da habt willen | ich waen iz iemen tv ### welt ir ihtes beginnen | so chvmet vns morgen frv ### vnde lat vns ellende | hint haben gemach ### ia waene ez von helden | mit solhem willen ie geschach
###### 1824 | ### do brahte man di geste | in einen witen sal ### den fvnden si berihtet | den recken vber al ### mit vil richen betten | lanch vnd breit ### in riet div vrowe crimhilt | div allergrozesten leit
###### 1825 | ### vil manigen kolter spaehe | von arraz man da sach ### der vil liehten pfellel | vnd manech pette dach ### von arabisschen siden | di beste mohten sin ### darvffe lagen listen | di gaben herlichen schin
###### 1826 | ### div dechlachen hermin | vil manegiv man da sach ### vnd von swarcem zoble | darvnder si ir gemach ### des nahtes shaffen solden | vnz an den liehten tach ### ein kvnech mit sinem gesinde | ni so herlich gelach
###### 1827 | ### owe der nahtselde | sprach giselher daz chint ### vnd owe miner frivnde | di mit vns chomen sint ### swi et ez vns min swester | so gvetliche erbot ### ich fvrhte daz wir mvezen | von ir schvlden ligen tot
###### 1828 | ### nv lazet iwer sorgen | sprach hagen der degen ### ich wil noch hinte selbe | der shiltwahte pflegen ### ich truwe vns wol behveten | vnz chomet der tach ### des sit gar an angest | so genese swer der mach
###### 1829 | ### do nigen si im alle | vnde sagten im des danch ### si giengen zv den betten | div wile was niht lanch ### daz sich geleget heten | di waetlichen man ### hagen der chvene | helt sich waffen began
###### 1830 | ### do sprach der videlaere | wolker der degen ### versmahet ez iv niht hagene | so wolde ich mit iv pflegen ### der shiltwahte hinte | vnz morgen frvo ### der helt vil minnechliche | danchet volkere do
###### 1831 | ### nv lon iv got von himele | vil lieber volker ### zallen minen sorgen | son gert ich niemens mer ### niwan ivch aleine | swa ich hete not ### ich sol ez wol verdienen | mich en wendes der tot
###### 1832 | ### do garten si sich beide | in liehtez ir gewant ### do nam ir ietwedere | den schilt an sine hant ### vnd giengen vz dem hvse | fver di tver stan ### do pflagen si der geste | daz was mit triwen getan
###### 1833 | ### volker der snelle | zv des sales want ### sinen shilt den gvten | leit er von der hant ### do gi er hin widere | di videl er genam ### do diente er sinen frivnden | als ez dem helde gezam
###### 1834 | ### vnder di tver des hvses | saz er fver den stein ### chvener videlaere | der wart ni dehein ### do im der seiten doenen | so svezechlich erclanch ### di stolzen ellenden | sagtens volkeren danch
###### 1835 | ### do chlvngen sine seiten | daz allez daz hvs erdoz ### sin ellen zv der fvoge | div beidiv waren groz ### ie svezer vnd svezer | er videln began ### do entswebete er an den betten | vil manegen sorgenden man
###### 1836 | ### do si entslaffen waren | vnd er daz ervant ### do nam der degen widere | den schilt an di hant ### vnd gie zv dem gademe | fver den tvrn stan ### vnd hvote der ellenden | vor den crimhilde man
###### 1837 | ### des nahtes wol emmitten | ine weiz iz e geschach ### daz volker der chvene | einen helm schinen sach ### verre vz einer vinster | di criemhilde man ### di wolden an den gestn | gerne shaden han getan
###### 1838 | ### do sprach der videlaere | frivnt hagene ### vns zimt disiv sorge | ensamt ce tragene ### ich sihe gewaffente livte | bi dem hvse sten ### als ich mich versinne | ich waene si wellent vns besten
###### 1839 | ### so swiget sprach do hagene | lat se vns her naher baz ### e si vnser werden innen | so wirt hi helmvaz ### verrvchet mit den swerten | von vnser zweier hant ### si werdent criemhilde vhin wider vebele gesant
###### 1840 | ### ein der hivnen rechen | vil schiere daz gesach ### daz div tver was behevtet | wi balde er do sprach ### des wir da heten willen | ian mag es niht ergan ### ich sihe den videlaere | an der schiltwahte stan
###### 1841 | ### der treit vf sinem hovbete | einen helm glanz ### lvter vnd herte | starch vnde ganz ### ovch lovhtent im di ringe | sam daz fiwer tvt ### bi im stet ovch hagene | des sint di geste wol behvt
###### 1842 | ### zehant si cherten widere | do volker daz ersach ### wider sinen gesellen | er zornechlichen sprach ### nv lat mich zv den recken | vor dem hvse gan ### ich wil vragen maere | der vrovn criemhilde man
###### 1843 | ### nein dvrch mine liebe | sprach do hagene ### chomt ir von dem hvse | di snellen degene ### bringent ivch mit swerten | vil lihte in soelhe not ### daz ich iv mvese helfen | vnd waer iz aller miner mage tot
###### 1844 | ### so wir danne beide | chomen in den strit ### ir zwene oder viere | in einer chvrcen zit ### sprvengen zv dem hvse | vnde taeten vns div leit ### an den slaffenden recken | div nimmer wuerden verchleit
###### 1845 | ### do sprach aber volker | so lat daz geschehen ### daz wir si bringen innen | daz ich si habe gesehen ### daz des iht haben lovgen | di criemhilde man ### daz si vngetriweliche | vil gerne heten getan
###### 1846 | ### zehant do rief in volker | hin engegene ### wi get ir svs gewaffent | ir snellen degene ### welt ir shachen riten | ir criemhilde man ### dar svlt ir mich ce helfe | vnde mine hergesellen han
###### 1847 | ### des antwurte im niemen | zornech was sin mvt ### pfi ir zagen boese | sprach der helt gvt ### wolt ir slaffende | vns enmordet han ### daz ist so gvten helden | noch vil selten her getan
###### 1848 | ### do wart der chveneginne | vil rehte geseit ### daz ir boten niht erwuorben | von schvlden was ir leit ### do fvgete si ez anders | vil grimmech was ir mvt ### des mvosen sit verderben | di helde chvne vnde gvt

<<< Übersicht <<< vorige Seite nächste Seite >>>